<?php

/**
 * @file
 * Drush integration related functions.
 */


/**
 * Implementation of hook_drush_command().
 *
 * In this hook, you specify which commands your
 * drush module makes available, what it does and
 * description.
 *
 * Notice how this structure closely resembles how
 * you define menu hooks.
 *
 * @See drush_parse_command() for a list of recognized keys.
 *
 * @return
 *   An associative array describing your command(s).
 */
function langcheck_drush_command() {
  $items = array();

  $items['langcheck'] = array(
    // the name of the function implementing your command.
    'callback'    => 'langcheck_drush_cb_langcheck',
    'description' => 'Check all installed modules for translation percentage.',
  );

  return $items;
}

/**
 * Implementation of hook_drush_help().
 *
 * This function is called whenever a drush user calls
 * 'drush help <name-of-your-command>'
 *
 * @param
 *   A string with the help section (prepend with 'drush:')
 *
 * @return
 *   A string with the help text for your command.
 */
function langcheck_drush_help($section) {
  switch ($section) {
    case 'drush:langcheck':
      return "syntax:\ndrush langcheck [check|result]\nDefault arguments is the 'check'";
  }
}

function langcheck_drush_cb_langcheck() {
  $args = func_get_args();
  if (!_langcheck_drush_langcheck_validate($args)) {
    return;
  }
  
  switch ($args[0]) {
    case 'check':
      module_load_include('inc', 'langcheck');
      $sandbox = array();
      langcheck_check_initialize($sandbox);

      if ($sandbox['results']['count_languages']) {
        $settings = variable_get('langcheck_settings', _langcheck_default_values('langcheck_settings'));
        $settings['check_batch']['num_of_files'] = 0;
        $settings['check_batch']['num_of_langs'] = 0;

        langcheck_check_doit($sandbox, $settings);
        langcheck_check_result_summary($sandbox);
        variable_set('langcheck_check_batch_result', $sandbox['results']);
      }      
      //no break;

    case 'result':
      $results = variable_get('langcheck_check_batch_result', NULL);
      if (!$results) {
        drush_print(dt("Has no stored result. Try this command\ndrush langcheck check"));
        return;
      }
      
      drush_print_table(_langcheck_drush_langcheck_result_table($results), TRUE);
      break;
  }
}

function _langcheck_drush_langcheck_validate(&$args) {
  $count = count($args);
  if (!$count) {
    $args[] = 'check';
    return TRUE;
  }

  $matches = NULL;
  if ($count == 1 AND (preg_match('/^(check|result)$/i', $args[0], $matches))) {
    $args[0] = strtolower($matches[1]);
    return TRUE;
  }
  else {
    drush_print(dt('Invalid arguments.'));
    drush_print(dt('Try this: drush help langcheck'));
    return FALSE;
  }
}

function _langcheck_drush_langcheck_result_table($results) {
  $row = 0;
  $rows = array();
  $rows[$row][] = array(
    dt('Module'),
  );
  foreach ($results['language_names'] as $langcode => $langname) {
    $rows[$row][] = $langname;
  }
  $rows[$row++][] = dt('Module state');

  foreach ($results['data_module'] as $module => $langs) {
    $excluded_module = in_array($module, $results['excluded_modules']);
    $detail = $results['sum_language'][$module];
    $rows[$row][] = $module;

    foreach ($langs as $langcode => $detail) {
      $rows[$row][] = ($excluded_module) ?
        '---.--%'
        :
        str_pad(sprintf('%0.2f%%', $detail['state'] * 100), 7, ' ', STR_PAD_LEFT)
      ;
    }

    $rows[$row][] = ($excluded_module) ?
      '---.--%'
      :
      str_pad(sprintf('%0.2f%%', $results['sum_language'][$module]['state'] * 100), 7, ' ', STR_PAD_LEFT)
    ;
    $row++;
  }

  $overall = 0;
  $rows[$row][] = dt('Language state');
  foreach ($results['sum_module'] as $langcode => $detail) {
    $overall += $detail['state'];
    $rows[$row][] = str_pad(sprintf('%0.2f%%', $detail['state'] * 100), 7, ' ', STR_PAD_LEFT);
  }
  $state = $overall / $results['count_languages'];
  $rows[$row++][] = str_pad(sprintf('%0.2f%%', ($overall / $results['count_languages']) * 100), 7, ' ', STR_PAD_LEFT);

  return $rows;
}

// vim: set ft=php syntax=php expandtab ts=2 sw=2 autoindent smartindent:
